@@ -224,4 +224,7 @@ def get_time_again(raw_time_str):
     start_time_str = str(start_time).split(' ')[0]
     end_time_str = str(end_time).split(' ')[0]
 
-    return [start_time_str, end_time_str]
+    if year_info or month_info or day_info:
+        return [start_time_str, end_time_str]
+    else:
+        return []
